pub type Task = LockedExternalTaskDto;Aliased Type
pub struct Task {Show 19 fields
pub activity_id: Option<String>,
pub activity_instance_id: Option<String>,
pub error_message: Option<String>,
pub error_details: Option<String>,
pub execution_id: Option<String>,
pub id: Option<String>,
pub lock_expiration_time: Option<String>,
pub process_definition_id: Option<String>,
pub process_definition_key: Option<String>,
pub process_definition_version_tag: Option<String>,
pub process_instance_id: Option<String>,
pub tenant_id: Option<String>,
pub retries: Option<i32>,
pub suspended: Option<bool>,
pub worker_id: Option<String>,
pub priority: Option<i64>,
pub topic_name: Option<String>,
pub business_key: Option<String>,
pub variables: Option<HashMap<String, VariableValueDto>>,
}Fields
activity_id: Option<String>The id of the activity that this external task belongs to.
activity_instance_id: Option<String>The id of the activity instance that the external task belongs to.
error_message: Option<String>The full error message submitted with the latest reported failure executing this task;null if no failure was reported previously or if no error message was submitted
error_details: Option<String>The error details submitted with the latest reported failure executing this task.null if no failure was reported previously or if no error details was submitted
execution_id: Option<String>The id of the execution that the external task belongs to.
id: Option<String>The id of the external task.
lock_expiration_time: Option<String>The date that the task’s most recent lock expires or has expired.
process_definition_id: Option<String>The id of the process definition the external task is defined in.
process_definition_key: Option<String>The key of the process definition the external task is defined in.
process_definition_version_tag: Option<String>The version tag of the process definition the external task is defined in.
process_instance_id: Option<String>The id of the process instance the external task belongs to.
tenant_id: Option<String>The id of the tenant the external task belongs to.
retries: Option<i32>The number of retries the task currently has left.
suspended: Option<bool>Whether the process instance the external task belongs to is suspended.
worker_id: Option<String>The id of the worker that posesses or posessed the most recent lock.
priority: Option<i64>The priority of the external task.
topic_name: Option<String>The topic name of the external task.
business_key: Option<String>The business key of the process instance the external task belongs to.
variables: Option<HashMap<String, VariableValueDto>>A JSON object containing a property for each of the requested variables. The key is the variable name, the value is a JSON object of serialized variable values with the following properties: